Commit: 1bc6ae8529bfe90b3b003ec877775b7b4c542e24
Author: Sergey Sharybin
Date:   Wed Jan 27 10:21:51 2016 +0100
Branches: master
https://developer.blender.org/rB1bc6ae8529bfe90b3b003ec877775b7b4c542e24

Buildbot: Fix for missing spnav for Linux builds

===================================================================

M       build_files/buildbot/config/blender_linux.cmake

===================================================================

diff --git a/build_files/buildbot/config/blender_linux.cmake 
b/build_files/buildbot/config/blender_linux.cmake
index ad343d8..4090941 100644
--- a/build_files/buildbot/config/blender_linux.cmake
+++ b/build_files/buildbot/config/blender_linux.cmake
@@ -91,7 +91,10 @@ set(OPENEXR_IMATH_LIBRARY     
"/opt/lib/openexr/lib/libImath.a"     CACHE STRING
 # JeMalloc library
 set(JEMALLOC_LIBRARY    "/opt/lib/jemalloc/lib/libjemalloc.a" CACHE STRING "" 
FORCE)
 
-# Foce some system libraries to be static
+# Space navigation
+set(SPACENAV_ROOT_DIR       "/opt/lib/libspnav" CACHE STRING "" FORCE)
+
+# Force some system libraries to be static
 set(FFTW3_LIBRARY       "/usr/lib/libfftw3.a" CACHE STRING "" FORCE)
 set(JPEG_LIBRARY        "/usr/lib/libjpeg.a"  CACHE STRING "" FORCE)
 set(PNG_LIBRARY         "/usr/lib/libpng.a"   CACHE STRING "" FORCE)

_______________________________________________
Bf-blender-cvs mailing list
[email protected]
http://lists.blender.org/mailman/listinfo/bf-blender-cvs

Reply via email to